import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'dart:convert';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'User Management App',
      home: Scaffold(
        appBar: AppBar(
          title: Text('User Management App'),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              UserEmailViewer(),
              SizedBox(height: 20),
              AddUserButton(),
            ],
          ),
        ),
      ),
    );
  }
}

class UserEmailViewer extends StatefulWidget {
  @override
  _UserEmailViewerState createState() => _UserEmailViewerState();
}

class _UserEmailViewerState extends State<UserEmailViewer> {
  List<String> _emails = [];

  Future<void> fetchUserEmails() async {
    try {
      final response = await http.get(Uri.parse('https://group-15-5.pvt.dsv.su.se/demo/all'));
      if (response.statusCode == 200) {
        List<dynamic> userData = jsonDecode(response.body);
        List<String> emails = userData.map((user) => user['email'].toString()).toList();
        setState(() {
          _emails = emails;
        });
      } else {
        throw Exception('Failed to load user emails: ${response.statusCode}');
      }
    } catch (e) {
      print('Error fetching user emails: $e');
      // Handle error gracefully, e.g., show a snackbar or retry mechanism
    }
  }

  @override
  void initState() {
    super.initState();
    fetchUserEmails();
  }

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () {
        showDialog(
          context: context,
          builder: (BuildContext context) {
            return AlertDialog(
              title: Text('User Emails'),
              content: SingleChildScrollView(
                child: ListBody(
                  children: _emails.map((email) => Text(email)).toList(),
                ),
              ),
              actions: <Widget>[
                TextButton(
                  child: Text('Close'),
                  onPressed: () {
                    Navigator.of(context).pop();
                  },
                ),
              ],
            );
          },
        );
      },
      child: Text('View User Emails'),
    );
  }
}

class AddUserButton extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(builder: (context) => AddUserDialog()),
        );
      },
      child: Text('Add User'),
    );
  }
}

class AddUserDialog extends StatelessWidget {
  final TextEditingController nameController = TextEditingController();
  final TextEditingController emailController = TextEditingController();

  Future<void> addUser(String name, String email) async {
    try {
      final response = await http.post(
        Uri.parse('https://group-15-5.pvt.dsv.su.se/demo/add'),
        body: {
          'name': name,
          'email': email,
        },
      );
      if (response.statusCode == 200) {
        // User added successfully
        print('User added successfully');
      } else {
        throw Exception('Failed to add user: ${response.statusCode}');
      }
    } catch (e) {
      print('Error adding user: $e');
      // Handle error gracefully, e.g., show a snackbar or retry mechanism
    }
  }

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: Text('Add User'),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          TextField(
            controller: nameController,
            decoration: InputDecoration(labelText: 'Name'),
          ),
          TextField(
            controller: emailController,
            decoration: InputDecoration(labelText: 'Email'),
          ),
        ],
      ),
      actions: [
        TextButton(
          onPressed: () {
            Navigator.of(context).pop();
          },
          child: Text('Cancel'),
        ),
        TextButton(
          onPressed: () {
            final String name = nameController.text;
            final String email = emailController.text;

            if (name.isNotEmpty && email.isNotEmpty) {
              addUser(name, email).then((_) {
                print('User added successfully');
              }).catchError((error) {
                print('Error adding user: $error');
              });
              Navigator.of(context).pop();
            } else {
              ScaffoldMessenger.of(context).showSnackBar(
                SnackBar(
                  content: Text('Please fill all fields with valid data'),
                  duration: Duration(seconds: 2),
                ),
              );
            }
          },
          child: Text('Add'),
        ),
      ],
    );
  }
}
